=== modified file '__init__.py'
--- __init__.py	2006-03-22 22:25:30 +0000
+++ __init__.py	2006-03-24 05:20:43 +0000
@@ -275,9 +275,22 @@
         return zap(checkout)
 
 
+class cmd_cbranch(bzrlib.commands.Command):
+    """
+    Create a new checkout, associated with a new repository branch. <BZRTOOLS>
+    
+    When you cbranch, bzr looks up the repository associated with your current
+    directory in branches.conf.  It creates a new branch in that repository
+    with the same name and relative path as the checkout you request.
+    """
+    takes_args = ["source", "target"]
+    def run(self, source, target):
+        from cbranch import cbranch
+        return cbranch(source, target)
+
 commands = [cmd_shelve, cmd_unshelve, cmd_shelf, cmd_clean_tree,
             cmd_graph_ancestry, cmd_fetch_ghosts, cmd_patch, cmd_shell,
-            cmd_branch_history, cmd_zap]
+            cmd_branch_history, cmd_zap, cmd_cbranch]
 
 
 command_decorators = []

=== added file 'cbranch.py'
--- cbranch.py	1970-01-01 00:00:00 +0000
+++ cbranch.py	2006-03-24 05:20:43 +0000
@@ -0,0 +1,30 @@
+# Copyright (C) 2006 Aaron Bentley
+# <aaron.bentley@utoronto.ca>
+#
+#    This program is free software; you can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
+#    the Free Software Foundation; either version 2 of the License, or
+#    (at your option) any later version.
+#
+#    This program is distributed in the hope that it will be useful,
+#    but WITHOUT ANY WARRANTY; without even the implied warranty of
+#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#    GNU General Public License for more details.
+#
+#    You should have received a copy of the GNU General Public License
+#    along with this program; if not, write to the Free Software
+#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from bzrlib.builtins import cmd_branch, cmd_checkout
+from bzrlib.config import LocationConfig
+from bzrlib.errors import BzrCommandError
+from bzrlib.osutils import pathjoin, basename, abspath
+
+def cbranch(from_location, to_location, revision=None):
+    config = LocationConfig(abspath(to_location))
+    b_root = config.get_user_option("cbranch_root")
+    if b_root is None:
+        raise BzrCommandError("Can't find cbranch_root in branches.conf")
+    b_loc = pathjoin(b_root, basename(to_location))
+    cmd_branch().run(from_location, b_loc, revision=revision)
+    cmd_checkout().run(b_loc, to_location, lightweight=True)

